# pedestal-inference

A collection of python tools for Bayesian analysis of plasma-edge Thomson-scattering data.

### Documentation

Package documentation is available at [pedestal-inference.readthedocs.io](https://pedestal-inference.readthedocs.io/en/latest/index.html)